@@ -402,7 +402,7 @@ def serve_favicon(request, handler, *rest):
     """
     if request.path == '/favicon.ico':
         pathname = zoom.tools.zoompath(
-            'web', 'themes', 'default', 'images', 'favicon.ico'
+            'zoom', '_assets', 'web', 'themes', 'default', 'images', 'favicon.ico'
         )
         return serve_response(pathname)
     else:
@@ -598,6 +598,12 @@ def display_errors(request, handler, *rest):
     """
     try:
         return handler(request, *rest)
+
+    except zoom.exceptions.ThemeTemplateMissingException:
+        return zoom.response.HTMLResponse(
+            zoom.templates.template_missing
+        )
+
     except Exception:
         msg = traceback.format_exc()
         logger = logging.getLogger(__name__)
