@@ -270,6 +270,25 @@ class Group(Record):
         }
         return my_apps
 
+    def get_app_ids(self):
+        """Return set of app group ids"""
+        return self.apps
+
+    def get_app_names(self):
+        """Return set of names of app groups"""
+        groups = self['__store']
+        lookup = {
+            g.group_id: g.name[2:]
+            for g in groups
+            if (g.name.startswith('a_'))
+        }
+        return set(map(lookup.get, self.get_app_ids()))
+
+    @property
+    def app_names(self):
+        """Return set of names of app groups"""
+        return self.get_app_names()
+
     @property
     def subgroups(self):
         """Return set of IDs of subgroups that are part of this group"""
@@ -293,7 +312,7 @@ class Group(Record):
     def administrators(self):
         """Returns the administrator group name"""
         store = self['__store']
-        admin_group = store.get(self['admin_group_id'])
+        admin_group = store.get(self.get('admin_group_id', None))
         if admin_group:
             return admin_group.name
         return 'nothing'
@@ -334,6 +353,8 @@ class Group(Record):
     def update_subgroups_by_id(self, subgroup_ids):
         """Post updated group subgroups"""
 
+        groups = self['__store']
+
         updated_subgroups = set(map(int, subgroup_ids))
 
         logger = logging.getLogger(__name__)
@@ -348,10 +369,10 @@ class Group(Record):
 
             group_lookup = {
                 group.group_id: group.name
-                for group in zoom.system.site.groups
+                for group in groups
             }
 
-            db = self['__store'].db
+            db = groups.db
 
             to_remove = existing_subgroups - updated_subgroups
             if to_remove:
@@ -389,16 +410,18 @@ class Group(Record):
         else:
             debug('subgroups unchanged')
 
-    def update_supergroups_by_id(self, role_ids, kind):
+    def update_supergroups_by_id(self, group_ids, kind):
         """Post updated group supergroups"""
 
-        updated = set(map(int, role_ids))
+        updated = set(map(int, group_ids))
 
         logger = logging.getLogger(__name__)
         debug = logger.debug
 
         debug('updating %s: %r', kind, updated)
 
+        groups = self['__store']
+
         # print(kind)
         existing = getattr(self, kind + 's')
         debug('existing %s: %r', kind, updated)
@@ -408,10 +431,10 @@ class Group(Record):
 
             group_lookup = {
                 group.group_id: group.name
-                for group in zoom.system.site.groups
+                for group in groups
             }
 
-            db = self['__store'].db
+            db = groups.db
 
             to_remove = existing - updated
             if to_remove:
@@ -450,9 +473,11 @@ class Group(Record):
             debug('%s unchanged', kind)
 
     def update_apps_by_id(self, app_ids):
+        """Update apps by app group ids"""
         return self.update_supergroups_by_id(app_ids, 'app')
 
     def update_roles_by_id(self, role_ids):
+        """Update roles by role group ids"""
         return self.update_supergroups_by_id(role_ids, 'role')
 
     def update_members_by_id(self, user_ids):
@@ -464,6 +489,7 @@ class Group(Record):
         debug = logger.debug
 
         db = self['__store'].db
+        users = zoom.users.Users(db)
 
         debug('updating members: %r', updated)
 
@@ -478,7 +504,7 @@ class Group(Record):
 
             user_lookup = {
                 user.user_id: user.username
-                for user in zoom.system.site.users
+                for user in users
             }
 
             to_remove = existing - updated
@@ -505,6 +531,28 @@ class Group(Record):
         else:
             debug('memberships unchanged')
 
+    def add_apps(self, app_names):
+        """Add apps to the group"""
+        logger = logging.getLogger(__name__)
+        debug = logger.debug
+        groups = self['__store']
+
+        for name in app_names:
+            debug('adding %s', name)
+            groups.add_app(name)
+            supergroup = groups.first(name='a_' + name)
+            if supergroup:
+                debug('adding supergroup %s to %s', name, self.name)
+                supergroup.add_subgroup(self)
+
+    def remove_apps(self, app_names):
+        """Remove apps from the group"""
+        groups = self['__store']
+        for name in app_names:
+            supergroup = groups.first(name='a_' + name)
+            if supergroup:
+                supergroup.remove_subgroup(self)
+
 
 class Groups(RecordStore):
 
@@ -525,7 +573,7 @@ class Groups(RecordStore):
             isinstance(locator, str) and self.first(name=locator)
         )
 
-    def add(self, name, group_type, description=''):
+    def add(self, name, group_type='U', description=''):
         """Add a group"""
         debug = logging.getLogger(__name__).debug
         group_id = self.put(
@@ -533,12 +581,52 @@ class Groups(RecordStore):
                 name=name,
                 type=group_type,
                 description=description,
+                admin_group_id=1,
             )
         )
         debug('created new group %r (%r)', name, group_id)
         audit('create group', name)
         return group_id
 
+    def add_app(self, name):
+        """Add an app"""
+        debug = logging.getLogger(__name__).debug
+        group_name = 'a_' + name
+        if not self.first(name=group_name):
+            group_id = self.put(
+                Group(
+                    name=group_name,
+                    type='A',
+                    description='%s application group' % name,
+                    admin_group_id=1,
+                )
+            )
+            debug('created new app group %r (%r)', group_name, group_id)
+            audit('create app group', group_name)
+            return group_id
+
+    def remove_app(self, name):
+        """Remove an app"""
+        debug = logging.getLogger(__name__).debug
+        group_name = 'a_' + name
+        if self.first(name=group_name):
+            self.delete(name=group_name)
+            audit('delete app group', name)
+            debug('deleted app group %r', group_name)
+
+    def __str__(self):
+        return str(
+            zoom.utils.ItemList(
+                ((
+                    group.group_id,
+                    group.name,
+                    group.type,
+                    group.description,
+                ) for group in self),
+                labels=('ID', 'Name', 'Type', 'Description')
+            )
+        )
+
 
 class SystemAttachment(Record):
     pass
